@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2015-2017 Samuel Thibault <samuel.thibault@ens-lyon.org>
+# Copyright (c) 2015-2018 Samuel Thibault <samuel.thibault@ens-lyon.org>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -35,12 +35,12 @@ then
     INIT+=TM$TOPMARGIN,BI$INNERMARGIN
   else
     # disable margins
-    INIT+=TM0,BM0,IM0,OM0
+    INIT+=TM0,BI0
   fi
 
 
   # Common options
-  INIT+="$(setCommonOptions)"
+  INIT+="$(commonOptions)"
 
   # Paper size
   INIT+=,CH$TEXTWIDTH,LP$TEXTHEIGHT
